import axios from 'axios';

const API_URL = 'https://api.example.com'; // Replace with your actual API URL

const apiClient = axios.create({
    baseURL: API_URL,
    headers: {
        'Content-Type': 'application/json',
    },
});

// Add request interceptor for authentication
apiClient.interceptors.request.use(
    (config) => {
        const token = localStorage.getItem('token');
        if (token) {
            config.headers.Authorization = `Bearer ${token}`;
        }
        return config;
    },
    (error) => {
        return Promise.reject(error);
    }
);

// Add response interceptor for error handling
apiClient.interceptors.response.use(
    (response) => response,
    (error) => {
        // Handle common errors here
        if (error.response && error.response.status === 401) {
            // Handle unauthorized access
            localStorage.removeItem('token');
            // Redirect to login or show notification
        }
        return Promise.reject(error);
    }
);

// Example API methods
export const userService = {
    login: (credentials) => apiClient.post('/auth/login', credentials),
    register: (userData) => apiClient.post('/auth/register', userData),
    getProfile: () => apiClient.get('/user/profile'),
};

export const contentService = {
    getItems: (params) => apiClient.get('/items', { params }),
    getItemById: (id) => apiClient.get(`/items/${id}`),
    createItem: (data) => apiClient.post('/items', data),
    updateItem: (id, data) => apiClient.put(`/items/${id}`, data),
    deleteItem: (id) => apiClient.delete(`/items/${id}`),
};

export default apiClient;
